#define MROP McopyInverted
#include "mfbmap.h"
#include "../../../../mfb/mfbblt.c"
